@@ -680,9 +680,6 @@ notify_func (const char *name,
 				case GTK_TOOLBAR_BOTH:
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(self.rbToolBoth),TRUE);
 				break;
-				case GTK_TOOLBAR_BOTH_HORIZ:
-					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(self.rbToolBothH),TRUE);
-				break;
 				default:
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(self.rbToolIcons),TRUE);
 				break;
@@ -1083,8 +1080,6 @@ Theme_Save (void)
 		fs = GTK_TOOLBAR_TEXT;
 	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbToolBoth)))
 		fs = GTK_TOOLBAR_BOTH;
-	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(self.rbToolBothH)))
-		fs = GTK_TOOLBAR_BOTH_HORIZ;
 	system_printf (CMD_XST " write %s%s int %d", KEY_GTK, "ToolbarStyle", fs);
 	
 	/* terminal */
@@ -1333,14 +1328,14 @@ Theme_Build_Objects ()
 		    (GtkAttachOptions) (table_attach_left_col_x),
 		    (GtkAttachOptions) (table_attach_left_col_y), 0, 0);
 			
-  label = gtk_radio_button_new_with_label (NULL, _("Centered"));
+  label = gtk_radio_button_new_with_label (NULL, _("Center"));
   rg_img = label;
   self.rbImgCent = label;
   gtk_box_pack_start(GTK_BOX(hbox),label,FALSE,TRUE,0);
-  label = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON(rg_img), _("Tiled"));
+  label = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON(rg_img), _("Tile"));
   self.rbImgTiled = label;
   gtk_box_pack_start(GTK_BOX(hbox),label,FALSE,TRUE,0);
-  label = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON(rg_img), _("Stretched"));
+  label = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON(rg_img), _("Stretch"));
   self.rbImgStr = label;
   gtk_box_pack_start(GTK_BOX(hbox),label,FALSE,TRUE,0);
 			
@@ -1384,11 +1379,6 @@ Theme_Build_Objects ()
   gtk_table_attach (GTK_TABLE (table), self.rbToolBoth, 2, 3, 1, 2,
 		    (GtkAttachOptions) (table_attach_left_col_x),
 		    (GtkAttachOptions) (table_attach_left_col_y), 0, 0);
-  self.rbToolBothH =  gtk_radio_button_new_with_label_from_widget 
-  						(GTK_RADIO_BUTTON(self.rbToolIcons), _("Both H"));
-  gtk_table_attach (GTK_TABLE (table), self.rbToolBothH, 3, 4, 1, 2,
-		    (GtkAttachOptions) (table_attach_left_col_x),
-		    (GtkAttachOptions) (table_attach_left_col_y), 0, 0);
 #else
   gtk_table_attach (GTK_TABLE (table), label, 0, 3, 10, 11,
 		    (GtkAttachOptions) (table_attach_left_col_x),
@@ -1406,11 +1396,8 @@ Theme_Build_Objects ()
   						(GTK_RADIO_BUTTON(self.rbToolIcons), _("Text"));
   gtk_box_pack_start(GTK_BOX(hbox), self.rbToolText, FALSE, TRUE, 0);
   self.rbToolBoth =  gtk_radio_button_new_with_label_from_widget 
-  						(GTK_RADIO_BUTTON(self.rbToolIcons), _("Both (icon above text)"));
+  						(GTK_RADIO_BUTTON(self.rbToolIcons), _("Both"));
   gtk_box_pack_start(GTK_BOX(hbox), self.rbToolBoth, FALSE, TRUE, 0);
-  self.rbToolBothH =  gtk_radio_button_new_with_label_from_widget 
-  						(GTK_RADIO_BUTTON(self.rbToolIcons), _("Both (icon left of text)"));
-  gtk_box_pack_start(GTK_BOX(hbox), self.rbToolBothH, FALSE, TRUE, 0);
 #endif
 
 #ifndef APPMGR_INTERFACE	
